@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-conduit
 version: 2.1.8
-id: http-conduit-2.1.8-e2c4d8f7b8297fdf1ac5b7f32d06d5dd
-key: httpc_2yxpgEgcRZwFfLz6pNTsQo
+id: http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
+key: httpc_CMwafdzv6hZ7PgczRI0cRM
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -22,18 +22,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http-conduit-2.1.8
-hs-libraries: HShttp-conduit-2.1.8-2yxpgEgcRZwFfLz6pNTsQo
+hs-libraries: HShttp-conduit-2.1.8-CMwafdzv6hZ7PgczRI0cRM
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
-    http-client-0.4.27-cb2c2811d5497a3b5f8310fdf3cadc3f
-    http-client-tls-0.2.2-a568dba4ad303022988fc1cb539c259c
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
+    http-client-tls-0.2.2-f98f7df0478363eb3e20cd852c79aa5a
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
 haddock-html: /usr/share/doc/haskell-http-conduit/html
